import { SerializableValue } from '@previewjs/serializable-values';
import { TypeAnalyzer, ValueType, CollectedTypes } from '@previewjs/type-analyzer';
import { Reader } from '@previewjs/vfs';
import { Logger } from 'pino';

type Analyzer = {
    typeAnalyzer: Omit<TypeAnalyzer, "dispose">;
    analyze: (filePaths: string[]) => Promise<{
        components: Component[];
        stories: Story[];
    }>;
    dispose: () => void;
};
type AnalyzerFactory = (options: {
    rootDir: string;
    reader?: Reader;
    logger?: Logger;
}) => Analyzer;
interface BasePreviewable {
    id: string;
    sourcePosition: FileSourcePosition;
}
interface Component extends BasePreviewable {
    exported: boolean;
    extractProps: () => Promise<ComponentProps>;
}
interface ComponentProps {
    props: ValueType;
    types: CollectedTypes;
}
interface Story extends BasePreviewable {
    extractArgs: () => Promise<StoryArgs | null>;
    associatedComponent: BasicComponent | null;
}
type StoryArgs = {
    sourcePosition: FileSourcePosition;
    value: SerializableValue;
};
type FileSourcePosition = {
    start: number;
    end: number;
};
type BasicComponent = Pick<Component, "id" | "extractProps">;

type AnalyzerFactoryOptions = Parameters<AnalyzerFactory>[0];
declare function factoryWithDefaultOptions(factory: (options: Required<AnalyzerFactoryOptions>) => Analyzer): AnalyzerFactory;

declare function generatePreviewableId(options: {
    filePath: string;
    name: string;
}): string;
declare function decodePreviewableId(id: string): {
    filePath: string;
    name: string;
};

export { Analyzer, AnalyzerFactory, BasePreviewable, BasicComponent, Component, ComponentProps, FileSourcePosition, Story, StoryArgs, decodePreviewableId, factoryWithDefaultOptions, generatePreviewableId };
